'use client';
import * as facelessUIImport from '@faceless-ui/modal';
import queryString from 'qs';
import React, { useCallback, useEffect, useState } from 'react';
import { toast } from 'react-toastify';
import { useRelatedCollections } from '../../fields/Relationship/AddNew/useRelatedCollections.js';
import { X } from '../../icons/X/index.js';
import { useComponentMap } from '../../providers/ComponentMap/index.js';
import { useConfig } from '../../providers/Config/index.js';
import { DocumentInfoProvider, useDocumentInfo } from '../../providers/DocumentInfo/index.js';
import { useFormQueryParams } from '../../providers/FormQueryParams/index.js';
import { useLocale } from '../../providers/Locale/index.js';
import { useTranslation } from '../../providers/Translation/index.js';
import { Gutter } from '../Gutter/index.js';
import { IDLabel } from '../IDLabel/index.js';
import { RenderTitle } from '../RenderTitle/index.js';
import { baseClass } from './index.js';
export const DocumentDrawerContent = ({ id: existingDocID, Header, collectionSlug, drawerSlug, onSave: onSaveFromProps })=>{
    const { useModal } = facelessUIImport;
    const config = useConfig();
    const { routes: { api: apiRoute }, serverURL } = config;
    const { closeModal, modalState, toggleModal } = useModal();
    const locale = useLocale();
    const { t } = useTranslation();
    const [docID, setDocID] = useState(existingDocID);
    const [isOpen, setIsOpen] = useState(false);
    const [collectionConfig] = useRelatedCollections(collectionSlug);
    const { formQueryParams } = useFormQueryParams();
    const formattedQueryParams = queryString.stringify(formQueryParams);
    const { componentMap } = useComponentMap();
    const { Edit } = componentMap[`${collectionSlug ? 'collections' : 'globals'}`][collectionSlug];
    const isEditing = Boolean(docID);
    const apiURL = docID ? `${serverURL}${apiRoute}/${collectionSlug}/${docID}?locale=${locale.code}` : null;
    const action = `${serverURL}${apiRoute}/${collectionSlug}${isEditing ? `/${docID}` : ''}?${formattedQueryParams}`;
    useEffect(()=>{
        setIsOpen(Boolean(modalState[drawerSlug]?.isOpen));
    }, [
        modalState,
        drawerSlug
    ]);
    const onLoadError = React.useCallback((data)=>{
        if (isOpen) {
            closeModal(drawerSlug);
            toast.error(data.errors?.[0].message || t('error:unspecific'));
        }
    }, [
        closeModal,
        drawerSlug,
        isOpen,
        t
    ]);
    const onSave = useCallback((args)=>{
        setDocID(args.doc.id);
        if (typeof onSaveFromProps === 'function') {
            void onSaveFromProps({
                ...args,
                collectionConfig
            });
        }
    }, [
        onSaveFromProps,
        collectionConfig
    ]);
    return /*#__PURE__*/ React.createElement(DocumentInfoProvider, {
        BeforeDocument: /*#__PURE__*/ React.createElement(Gutter, {
            className: `${baseClass}__header`
        }, /*#__PURE__*/ React.createElement("div", {
            className: `${baseClass}__header-content`
        }, /*#__PURE__*/ React.createElement("h2", {
            className: `${baseClass}__header-text`
        }, Header || /*#__PURE__*/ React.createElement(RenderTitle, {
            element: "span"
        })), /*#__PURE__*/ React.createElement("button", {
            "aria-label": t('general:close'),
            className: `${baseClass}__header-close`,
            onClick: ()=>toggleModal(drawerSlug),
            type: "button"
        }, /*#__PURE__*/ React.createElement(X, null))), /*#__PURE__*/ React.createElement(DocumentTitle, null)),
        action: action,
        apiURL: apiURL,
        collectionSlug: collectionConfig.slug,
        disableActions: true,
        disableLeaveWithoutSaving: true,
        // Do NOT pass in the docPermissions we have here. This is because the permissions we have here do not have their where: { } returns resolved.
        // If we set it to null though, the DocumentInfoProvider will fully-fetch the permissions from the server, and the where: { } returns will be resolved.
        docPermissions: null,
        // Same reason as above. We need to fully-fetch the docPreferences from the server. This is done in DocumentInfoProvider if we set it to null here.
        hasSavePermission: null,
        // isLoading,
        id: docID,
        isEditing: isEditing,
        onLoadError: onLoadError,
        onSave: onSave
    }, Edit);
};
const DocumentTitle = ()=>{
    const { id, title } = useDocumentInfo();
    return id && id !== title ? /*#__PURE__*/ React.createElement(IDLabel, {
        id: id.toString()
    }) : null;
};

//# sourceMappingURL=DrawerContent.js.map