'use client';
import { getTranslation } from '@payloadcms/translations';
import { useEntityVisibility } from '@payloadcms/ui/providers/EntityVisibility';
import LinkWithDefault from 'next/link.js';
import React, { Fragment } from 'react';
import { Chevron } from '../../icons/Chevron/index.js';
import { useAuth } from '../../providers/Auth/index.js';
import { useConfig } from '../../providers/Config/index.js';
import { useTranslation } from '../../providers/Translation/index.js';
import { EntityType, groupNavItems } from '../../utilities/groupNavItems.js';
import { NavGroup } from '../NavGroup/index.js';
import { useNav } from './context.js';
const baseClass = 'nav';
export const DefaultNavClient = ()=>{
    const { permissions } = useAuth();
    const { isEntityVisible } = useEntityVisibility();
    const { collections, globals, routes: { admin } } = useConfig();
    const { i18n } = useTranslation();
    const { navOpen } = useNav();
    const groups = groupNavItems([
        ...collections.filter(({ slug })=>isEntityVisible({
                collectionSlug: slug
            })).map((collection)=>{
            const entityToGroup = {
                type: EntityType.collection,
                entity: collection
            };
            return entityToGroup;
        }),
        ...globals.filter(({ slug })=>isEntityVisible({
                globalSlug: slug
            })).map((global)=>{
            const entityToGroup = {
                type: EntityType.global,
                entity: global
            };
            return entityToGroup;
        })
    ], permissions, i18n);
    return /*#__PURE__*/ React.createElement(Fragment, null, groups.map(({ entities, label }, key)=>{
        return /*#__PURE__*/ React.createElement(NavGroup, {
            key: key,
            label: label
        }, entities.map(({ type, entity }, i)=>{
            let entityLabel;
            let href;
            let id;
            if (type === EntityType.collection) {
                href = `${admin}/collections/${entity.slug}`;
                entityLabel = getTranslation(entity.labels.plural, i18n);
                id = `nav-${entity.slug}`;
            }
            if (type === EntityType.global) {
                href = `${admin}/globals/${entity.slug}`;
                entityLabel = getTranslation(entity.label, i18n);
                id = `nav-global-${entity.slug}`;
            }
            const Link = LinkWithDefault.default || LinkWithDefault;
            const LinkElement = Link || 'a';
            return /*#__PURE__*/ React.createElement(LinkElement, {
                className: `${baseClass}__link`,
                href: href,
                id: id,
                key: i,
                tabIndex: !navOpen ? -1 : undefined
            }, /*#__PURE__*/ React.createElement("span", {
                className: `${baseClass}__link-icon`
            }, /*#__PURE__*/ React.createElement(Chevron, {
                direction: "right"
            })), /*#__PURE__*/ React.createElement("span", {
                className: `${baseClass}__link-label`
            }, entityLabel));
        }));
    }));
};

//# sourceMappingURL=index.client.js.map