'use client';
import React, { useCallback } from 'react';
import { FieldError } from '../../forms/FieldError/index.js';
import { FieldLabel } from '../../forms/FieldLabel/index.js';
import { useFormFields } from '../../forms/Form/context.js';
import { useField } from '../../forms/useField/index.js';
import { useTranslation } from '../../providers/Translation/index.js';
import { fieldBaseClass } from '../shared/index.js';
export const ConfirmPassword = (props)=>{
    const { disabled } = props;
    const password = useFormFields(([fields])=>fields?.password);
    const { t } = useTranslation();
    const validate = useCallback((value)=>{
        if (!value) {
            return t('validation:required');
        }
        if (value === password?.value) {
            return true;
        }
        return t('fields:passwordsDoNotMatch');
    }, [
        password,
        t
    ]);
    const path = 'confirm-password';
    const { setValue, showError, value } = useField({
        disableFormData: true,
        path,
        validate
    });
    return /*#__PURE__*/ React.createElement("div", {
        className: [
            fieldBaseClass,
            'confirm-password',
            showError && 'error'
        ].filter(Boolean).join(' ')
    }, /*#__PURE__*/ React.createElement(FieldError, {
        path: path
    }), /*#__PURE__*/ React.createElement(FieldLabel, {
        htmlFor: "field-confirm-password",
        label: t('authentication:confirmPassword'),
        required: true
    }), /*#__PURE__*/ React.createElement("input", {
        autoComplete: "off",
        disabled: !!disabled,
        id: "field-confirm-password",
        name: "confirm-password",
        onChange: setValue,
        type: "password",
        value: value || ''
    }));
};

//# sourceMappingURL=index.js.map